# Secoda Common

Secoda Common library holds common codes among micro services in Secoda.
For information about Secoda and our other services, visit the [main repository](https://github.com/secoda/secoda). Please also see our instructions for a [quick start](https://github.com/secoda/secoda/blob/master/docs/installation.md#bootstrap-a-default-version-of-secoda-using-docker) setup  of Secoda with dummy data, and an [overview of the architecture](https://github.com/secoda/secoda/blob/master/docs/architecture.md#architecture).

## Requirements
- Python >= 3.6

## Doc
- https://www.secoda.co/secoda/
